- Upload some datasets
- Add filters to search

- Upload folder, not zip
- Think about download
- Implement download endpoint
- Add downlaod to python library
- Write Java library

- Add CCD0 summary tree
- Add simple tree ESS
